
/*
	KeyboardApplet class
	
	accepts user input text
	displays statistics on typing text with qwerty and dvorak keyboards
	loads keyboard image used for qwerty and dvorak keyboards

	author: JAM (Jon A. Maxwell)
	email: jmaxwell@acm.vt.edu
	date: Mar 20 1998
	
	modification:  Addition of 6 more layouts.  
	               Michael Capewell
	               smozoma@yahoo.com
	               June 19, 2005
*/

import java.awt.*;
import java.applet.*;


public class KeyboardApplet extends Applet {

	TextArea text = new TextArea(5, 80);
	Button calc = new Button("Calculate");

	Keyboard dvorak, qwerty, cdvorak, cqwerty, cqwerty2, klausler2, arensito, c_adjacent, c_close;
	KeyStats dvorakStats, qwertyStats, cdvorakStats, cqwertyStats, cqwerty2Stats, 
	         klausler2Stats, arensitoStats, c_adjacentStats, c_closeStats;
	
	String dvorakKeymap[] = {
		"`1234567890[]\\"  ,  "~!@#$%^&*(){}|",
		" ',.pyfgcrl/="    ,  " \"<>PYFGCRL?+",
		" aoeuidhtns-\n"   ,  " AOEUIDHTNS_\n",
		"  ;qjkxbmwvz"     ,  "  :QJKXBMWVZ",
		"  "               ,  ""   
		};
	String arensitoKeymap[] = {
		"`1234567890[]\\"  ,  "~!@#$%^&*(){}|",
		" ql.p';fudk/="  ,   " QL>P\":FUDK?+"  ,
		" arenbgsito-\n" ,   " ARENBGSITO_\n",
		"  zw,hjvcymx"   ,   "  ZW<HJVCYMX"   ,
		      "  "       ,         ""
		};
	String cdvorakKeymap[] = {
		"`1234567890[]\\"  ,  "~!@#$%^&*(){}|",
		" ',.pyqfgrk/="    ,  " \"<>PYQFGRK?+",
		" oaeiudhtns-\n"   ,  " OAEIUDHTNS_\n",
		"  zxcvjlmwb;"     ,  "  ZXCVJLMWB:",
		"  "               ,  ""   
		};		
	String klausler2Keymap[] = {
		"`1234567890[]\\"  ,  "~!@#$%^&*(){}|",
		" k,uypwlmfc/="    ,  " K<UYPWLMFC?+",
		" oaeidrnths-\n"   ,  " OAEIDRNTHS_\n",
		"  q.';zxvgbj"     ,  "  Q<\":ZXVGBJ",
		"  "               ,  ""   
		};
	String cqwertyKeymap[] = {
		"`1234567890-=\\",   "~!@#$%^&*()_+|" ,
		" qwdrfjyplk[]"  ,   " QWDRFJYPLK{}"  ,
		" asetghuio,'\n" ,   " ASETGHUIO<\"\n",
		"  zxcvbnm;./"   ,   "  ZXCVBNM:>?"   ,
		      "  "       ,         ""
		};
	String c_adjacentKeymap[] = {
		"`1234567890[]\\"  ,  "~!@#$%^&*(){}|",
		" .mydg;w,h'/="  ,   " >MYDG:W<H\"?+"  ,
		" oresfktina-\n" ,   " ORESFKTINA_\n",
		"  xczvqbpulj"   ,   "  XCZVQBPULJ"   ,
		      "  "       ,         ""
		};
    String c_closeKeymap[] = {
		"`1234567890[]\\"  ,  "~!@#$%^&*(){}|",
		" ;l.fbzmupq/="  ,   " :L<FBZMUPQ?+"  ,
		" erosgvtina-\n" ,   " EROSGVTINA_\n",
		"  jh,cxkdyw'"   ,   "  JH<CXKDYW\""   ,
		      "  "       ,         ""
		};		

		
//	setup applet gui, keyboards

	public void init() {

		// load images
      Image qwertyImage = null;
      Image dvorakImage = null;
      Image cqwertyImage = null;
      Image cdvorakImage = null;
      Image klausler2Image = null;
      Image arensitoImage = null;
      Image c_adjacentImage = null;
      Image c_closeImage = null;
      try {
         qwertyImage = Toolkit.getDefaultToolkit().getImage( getClass().getClassLoader().getResource("keyboard.jpg"));
         dvorakImage = qwertyImage;
         cdvorakImage = qwertyImage;
         cqwertyImage = qwertyImage;
         klausler2Image = qwertyImage;
         arensitoImage = qwertyImage;
         c_adjacentImage = qwertyImage;
         c_closeImage = qwertyImage;
      }
      catch (Exception ex) {
      }

		// qwerty, dvorak keyboard
		qwerty = new Keyboard(qwertyImage);
		dvorak = new Keyboard(dvorakImage);
		cqwerty = new Keyboard(cqwertyImage);
		cdvorak = new Keyboard(cdvorakImage);
		klausler2 = new Keyboard(klausler2Image);
		arensito = new Keyboard(arensitoImage);
		c_adjacent = new Keyboard(c_adjacentImage);
		c_close = new Keyboard(c_closeImage);
		for (int i=0; i < dvorakKeymap.length; i+=2) {
			dvorak.setRow(i/2,Keyboard.LOWERCASE, dvorakKeymap[i]);
			dvorak.setRow(i/2,Keyboard.UPPERCASE, dvorakKeymap[i+1]);
		}
		for (int i=0; i < dvorakKeymap.length; i+=2) {
			cdvorak.setRow(i/2,Keyboard.LOWERCASE, cdvorakKeymap[i]);
			cdvorak.setRow(i/2,Keyboard.UPPERCASE, cdvorakKeymap[i+1]);
		}
		for (int i=0; i < dvorakKeymap.length; i+=2) {
			cqwerty.setRow(i/2,Keyboard.LOWERCASE, cqwertyKeymap[i]);
			cqwerty.setRow(i/2,Keyboard.UPPERCASE, cqwertyKeymap[i+1]);
		}
		for (int i=0; i < dvorakKeymap.length; i+=2) {
			klausler2.setRow(i/2,Keyboard.LOWERCASE, klausler2Keymap[i]);
			klausler2.setRow(i/2,Keyboard.UPPERCASE, klausler2Keymap[i+1]);
		}
		for (int i=0; i < dvorakKeymap.length; i+=2) {
			arensito.setRow(i/2,Keyboard.LOWERCASE, arensitoKeymap[i]);
			arensito.setRow(i/2,Keyboard.UPPERCASE, arensitoKeymap[i+1]);
		}
		for (int i=0; i < dvorakKeymap.length; i+=2) {
			c_adjacent.setRow(i/2,Keyboard.LOWERCASE, c_adjacentKeymap[i]);
			c_adjacent.setRow(i/2,Keyboard.UPPERCASE, c_adjacentKeymap[i+1]);
		}
		for (int i=0; i < dvorakKeymap.length; i+=2) {
			c_close.setRow(i/2,Keyboard.LOWERCASE, c_closeKeymap[i]);
			c_close.setRow(i/2,Keyboard.UPPERCASE, c_closeKeymap[i+1]);
		}

		
		// stats
		dvorakStats = new KeyStats();
		dvorakStats.calculate("", dvorak);
		qwertyStats = new KeyStats();
		qwertyStats.calculate("", qwerty);
		cdvorakStats = new KeyStats();
		cdvorakStats.calculate("", cdvorak);
		cqwertyStats = new KeyStats();
		cqwertyStats.calculate("", cqwerty);
		klausler2Stats = new KeyStats();
		klausler2Stats.calculate("", klausler2);
		arensitoStats = new KeyStats();
		arensitoStats.calculate("", arensito);
		c_adjacentStats = new KeyStats();
		c_adjacentStats.calculate("", c_adjacent);
		c_closeStats = new KeyStats();
		c_closeStats.calculate("", c_close);


		// gui

		this.setBackground(new Color(220,220,220));
		resize(620,1550);

		// I know, I know, GridbagLayout... or something
		
		GridBagLayout gridbag = new GridBagLayout();
        GridBagConstraints c = new GridBagConstraints();
        setLayout(gridbag);

		// textPanel: text area and calculate button
		Panel calcPanel = new Panel();
		calcPanel.setLayout( new FlowLayout() );
		calcPanel.add(calc);
		//
		Panel textPanel = new Panel();
		textPanel.setLayout( new BorderLayout() );
		textPanel.add("Center",text);
		textPanel.add("South",calcPanel);

		//========================================================
		// dvorakStatsPanel: dvorak label and dvorakStats
		Panel dvorakStatsPanel = new Panel();
		Label dvorakLabel = new Label("Dvorak", Label.LEFT);
		dvorakLabel.setFont(new Font("Dialog", Font.BOLD, 16));
		dvorakStatsPanel.setLayout( new BorderLayout() );
		dvorakStatsPanel.add("Center", dvorakStats);
		dvorakStatsPanel.add("North", dvorakLabel);

		// qwertyStatsPanel: qwerty label and qwertyStats
		Panel qwertyStatsPanel = new Panel();
		Label qwertyLabel = new Label("Qwerty", Label.LEFT);
		qwertyLabel.setFont(new Font("Dialog", Font.BOLD, 16));
		qwertyStatsPanel.setLayout( new BorderLayout() );
		qwertyStatsPanel.add("Center", qwertyStats);
		qwertyStatsPanel.add("North", qwertyLabel);
		
		// cdvorakStatsPanel: cdvorak label and cdvorakStats
		Panel cdvorakStatsPanel = new Panel();
		Label cdvorakLabel = new Label("Capewell-Dvorak", Label.LEFT);
		cdvorakLabel.setFont(new Font("Dialog", Font.BOLD, 16));
		cdvorakStatsPanel.setLayout( new BorderLayout() );
		cdvorakStatsPanel.add("Center", cdvorakStats);
		cdvorakStatsPanel.add("North", cdvorakLabel);

		// cqwertyStatsPanel: cqwerty label and cqwertyStats
		Panel cqwertyStatsPanel = new Panel();
		Label cqwertyLabel = new Label("Capewell-Qwerty", Label.LEFT);
		cqwertyLabel.setFont(new Font("Dialog", Font.BOLD, 16));
		cqwertyStatsPanel.setLayout( new BorderLayout() );
		cqwertyStatsPanel.add("Center", cqwertyStats);
		cqwertyStatsPanel.add("North", cqwertyLabel);
		
		// klausler2StatsPanel: klausler2 label and klausler2Stats
		Panel klausler2StatsPanel = new Panel();
		Label klausler2Label = new Label("Klausler2", Label.LEFT);
		klausler2Label.setFont(new Font("Dialog", Font.BOLD, 16));
		klausler2StatsPanel.setLayout( new BorderLayout() );
		klausler2StatsPanel.add("Center", klausler2Stats);
		klausler2StatsPanel.add("North", klausler2Label);

		// arensitoStatsPanel: arensito label and arensitoStats
		Panel arensitoStatsPanel = new Panel();
		Label arensitoLabel = new Label("Arensito", Label.LEFT);
		arensitoLabel.setFont(new Font("Dialog", Font.BOLD, 16));
		arensitoStatsPanel.setLayout( new BorderLayout() );
		arensitoStatsPanel.add("Center", arensitoStats);
		arensitoStatsPanel.add("North", arensitoLabel);
		
		// arensitoStatsPanel: c_adjacent label and c_adjacentStats
		Panel c_adjacentStatsPanel = new Panel();
		Label c_adjacentLabel = new Label("Capewell (Adjacent)", Label.LEFT);
		c_adjacentLabel.setFont(new Font("Dialog", Font.BOLD, 16));
		c_adjacentStatsPanel.setLayout( new BorderLayout() );
		c_adjacentStatsPanel.add("Center", c_adjacentStats);
		c_adjacentStatsPanel.add("North", c_adjacentLabel);
		
		// arensitoStatsPanel: arensito label and arensitoStats
		Panel c_closeStatsPanel = new Panel();
		Label c_closeLabel = new Label("Capewell (Close)", Label.LEFT);
		c_closeLabel.setFont(new Font("Dialog", Font.BOLD, 16));
		c_closeStatsPanel.setLayout( new BorderLayout() );
		c_closeStatsPanel.add("Center", c_closeStats);
		c_closeStatsPanel.add("North", c_closeLabel);
		
		//========================================================
		// dvorakPanel: dvorakStatsPanel and dvorak keyboard
		Panel dvorakPanel = new Panel();
		dvorakPanel.setLayout( new BorderLayout() );
		dvorakPanel.add("North", dvorakStatsPanel);
		dvorakPanel.add("Center",dvorak);
		
		// qwertyPanel: qwertyStatsPanel and qwerty keyboard
		Panel qwertyPanel = new Panel();
		qwertyPanel.setLayout( new BorderLayout() );
		qwertyPanel.add("North", qwertyStatsPanel);
		qwertyPanel.add("Center",qwerty);

		// cdvorakPanel: cdvorakStatsPanel and cdvorak keyboard
		Panel cdvorakPanel = new Panel();
		cdvorakPanel.setLayout( new BorderLayout() );
		cdvorakPanel.add("North", cdvorakStatsPanel);
		cdvorakPanel.add("Center",cdvorak);
		
		// cqwertyPanel: cqwertyStatsPanel and cqwerty keyboard
		Panel cqwertyPanel = new Panel();
		cqwertyPanel.setLayout( new BorderLayout() );
		cqwertyPanel.add("North", cqwertyStatsPanel);
		cqwertyPanel.add("Center",cqwerty);

		// klausler2Panel: klausler2StatsPanel and klausler2 keyboard
		Panel klausler2Panel = new Panel();
		klausler2Panel.setLayout( new BorderLayout() );
		klausler2Panel.add("North", klausler2StatsPanel);
		klausler2Panel.add("Center",klausler2);
		
		// arensitoPanel: arensitoStatsPanel and arensito keyboard
		Panel arensitoPanel = new Panel();
		arensitoPanel.setLayout( new BorderLayout() );
		arensitoPanel.add("North", arensitoStatsPanel);
		arensitoPanel.add("Center",arensito);

		// arensitoPanel: c_adjacentStatsPanel and c_adjacent keyboard
		Panel c_adjacentPanel = new Panel();
		c_adjacentPanel.setLayout( new BorderLayout() );
		c_adjacentPanel.add("North", c_adjacentStatsPanel);
		c_adjacentPanel.add("Center",c_adjacent);

		// c_closePanel: c_closeStatsPanel and c_close keyboard
		Panel c_closePanel = new Panel();
		c_closePanel.setLayout( new BorderLayout() );
		c_closePanel.add("North", c_closeStatsPanel);
		c_closePanel.add("Center",c_close);

		//========================================================
		// displayPanel: dvorakPanel and qwertyPanel
		Panel displayPanel = new Panel();
		displayPanel.setLayout( new FlowLayout() );
		displayPanel.add("West",dvorakPanel);
		displayPanel.add("East",qwertyPanel);
		displayPanel.add("West",cdvorakPanel);
		displayPanel.add("East",cqwertyPanel);
		displayPanel.add("West",klausler2Panel);
		displayPanel.add("East",arensitoPanel);
		displayPanel.add("West",c_adjacentPanel);
		displayPanel.add("East",c_closePanel);

		// this panel: textPanel and displayPanel
		setLayout( new BorderLayout() );
		add("North",textPanel);
		add("Center",displayPanel);
	}



// calculate

	public boolean handleEvent(Event event) {
		if (event.id == Event.ACTION_EVENT && event.target == calc) {
			calc.disable();
			dvorakStats.calculate(text.getText(), dvorak);
			qwertyStats.calculate(text.getText(), qwerty);
			cdvorakStats.calculate(text.getText(), cdvorak);
			cqwertyStats.calculate(text.getText(), cqwerty);
			klausler2Stats.calculate(text.getText(), klausler2);
			arensitoStats.calculate(text.getText(), arensito);
			c_adjacentStats.calculate(text.getText(), c_adjacent);
			c_closeStats.calculate(text.getText(), c_close);
			calc.enable();
			return true;
		}
		return super.handleEvent(event);
	}






}


